Changelog
=========

1.99.7
------
 - don't remove asterisks from site root quick search query

1.99.6
------
 - don't remove asterisks from shared tool quick search query

1.99.5
------
 - provide document OID instead of original document when removing a document from index

1.99.4
------
 - code refactoring
 - updated doctests

1.99.3
------
 - updated fulltext queries
 - update current datetime getter
 - code cleanup

1.99.2
------
 - added aggregated filters support

1.99.1
------
 - removed index checker for search folders
 - added edit forms content getters

1.99.0.1
--------
 - packaging issue

1.99.0
------
 - first preliminary release
